#!/bin/bash
# Comments start with a "#" they are ignored

# Remove the "#" to enable tracing
# set -x

# Copyright (c) 2019 All Rights Reserved Basement Supercomputing

# Assign file names
CSVFILE="bank.csv"
TEMPNEWCSVFILE="temp.csv"
NEWCSVFILENAME="bank-cleaned"
CSVTAG=".csv"
SINGLE="single"
MARRIED="married"
DIVORCED="divorced"

# Remove any old files
/bin/rm $CSVFILE* &> /dev/null

# Download the file
echo "Downloading File $CSVFILE"
wget https://www.clustermonkey.net/download/Hands-on_Hadoop_Spark/bank.csv &>/dev/null

# Check to make sure download worked
if [ "$?" -ne 0 ]; then
   echo "There was en error with the download. Exiting"
   exit 1; 
else
   echo "The download worked"
fi

# Read the file:
# only interested in "age";"job";"marital";"balance"
# remove any old files
/bin/rm $TEMPNEWCSVFILE &>/dev/null
while IFS= read -r line
do
  AGE=`echo "$line"|gawk -F\; '{print $1}'`
  JOB=`echo "$line"|gawk -F\; '{print $2}'`
  MARITAL=`echo "$line"|gawk -F\; '{print $3}'`
  BALANCE=`echo "$line"|gawk -F\; '{print $6}'`
  echo $AGE, $JOB, $MARITAL, $BALANCE >>$TEMPNEWCSVFILE
done < "$CSVFILE"

# rename file with today's date
DATE=`date +%F`
NEWCSVFILE="$NEWCSVFILENAME-$DATE$CSVTAG"
/bin/mv $TEMPNEWCSVFILE $NEWCSVFILE
# Now remove the " using sed
# -i means in place, a new file can be created
# by using
#  sed -e  's/"//g' $NEWCSVFILE >New-file.csv
echo "Removing extra characters"
sed -i 's/"//g' $NEWCSVFILE

TOTAL_RECORDS=`cat $NEWCSVFILE|wc -l`
echo "A total of $TOTAL_RECORDS records were processed"
# Now create a file for each marital status

grep $SINGLE $NEWCSVFILE > $SINGLE-$NEWCSVFILE
grep $DIVORCED $NEWCSVFILE > $DIVORCED-$NEWCSVFILE
grep $MARRIED $NEWCSVFILE > $MARRIED-$NEWCSVFILE

echo "Copying to HDFS"
hdfs dfs -rm -skipTrash $NEWCSVFILE &>/dev/null

hdfs dfs -put $NEWCSVFILE 



echo "Finished"


